@@ -3,7 +3,7 @@ package Module::HideRename;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-02-13'; # DATE
 our $DIST = 'Module-HideRename'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -49,7 +49,7 @@ sub _hiderename_modules {
                 or warn "Can't rename $path -> $new_path: $!";
         }
     }
-    1;
+    [200];
 }
 
 $SPEC{hiderename_modules} = {
@@ -57,7 +57,6 @@ $SPEC{hiderename_modules} = {
     args => {
         %args0_modules,
     },
-    result_naked => 1,
 };
 sub hiderename_modules {
     $unhide = 0;
@@ -69,7 +68,6 @@ $SPEC{unhiderename_modules} = {
     args => {
         %args0_modules,
     },
-    result_naked => 1,
 };
 sub unhiderename_modules {
     $unhide = 1;
@@ -91,7 +89,7 @@ Module::HideRename - Hide modules by renaming them
 
 =head1 VERSION
 
-This document describes version 0.002 of Module::HideRename (from Perl distribution Module-HideRename), released on 2020-02-13.
+This document describes version 0.003 of Module::HideRename (from Perl distribution Module-HideRename), released on 2020-02-13.
 
 =head1 SYNOPSIS
 
@@ -119,7 +117,7 @@ But sometimes you actually need to hide (rename) the module files.
 
 Usage:
 
- hiderename_modules(%args) -> any
+ hiderename_modules(%args) -> [status, msg, payload, meta]
 
 This function is not exported by default, but exportable.
 
@@ -132,6 +130,15 @@ Arguments ('*' denotes required arguments):
 
 =back
 
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
 Return value:  (any)
 
 
@@ -140,7 +147,7 @@ Return value:  (any)
 
 Usage:
 
- unhiderename_modules(%args) -> any
+ unhiderename_modules(%args) -> [status, msg, payload, meta]
 
 This function is not exported by default, but exportable.
 
@@ -153,6 +160,15 @@ Arguments ('*' denotes required arguments):
 
 =back
 
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
 Return value:  (any)
 
 =head1 HOMEPAGE
